# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _
from jumbo.db.models import DateModel, UserModel, StatusModel, OrderedModel
#FIXME
#from jumbo.apps.l10n.models import Country

ADDRESS_TYPE_CHOICES = (
    (1, _(u'Corso')),
    (2, _(u'Largo')),
    (3, _(u'Località')),
    (4, _(u'Piazza')),
    (5, _(u'Strada/Stretto')),
    (6, _(u'Traversa')),
    (7, _(u'Via')),
    (8, _(u'Viale')),
    (9, _(u'Vicolo/Vico')),
    (10, _(u'Circonvallazione')),
    (11, _(u'Frazione')),
    (12, _(u'Rione')),
    (13, _(u'Salita')),
    (14, _(u'Contrada')),
    (15, _(u'Statale')),
    (16, _(u'Autostrada')),
    (17, _(u'Cascina')),
    (18, _(u'Parco')),
    (19, _(u'Spalto')),
    (20, _(u'Tangenziale')),
    (21, _(u'Zona industriale')),
    (22, _(u'Borgo')),
    (23, _(u'Galleria')),
    (24, _(u'Piazzale')),
    (25, _(u'Corte')),
    (26, _(u'Centro')),
    (27, _(u'Foro')),
    (28, _(u'Lungo/Lungomare')),
    (29, _(u'Calle')),
    (30, _(u'Riviera')),
    (31, _(u'Villaggio')),
    (32, _(u'Passaggio')),
    (33, _(u'Borgata')),
    (34, _(u'Lungolago')),
)

#######################################
# INDIRIZZO FINALITA                  #
#######################################
class AddressScope (DateModel, UserModel, StatusModel, OrderedModel):
    ## ForeignKey
    ## Campi
    name = models.CharField (
        unique = True,
        max_length = 100,
        db_index = True,
        verbose_name = _("name"),
    )
    is_invoice_address = models.BooleanField(
        default=False,
        verbose_name=_('Invoice Address'),
        help_text = _("If this address scope is an invoice address")
    )
    is_shipping_address = models.BooleanField(
        default=False,
        verbose_name=_('Shipping Address'),
        help_text = _("If this address scope is a shipping address")
    )

    class Meta:
        verbose_name = _("address scope")
        verbose_name_plural = _("address scopes")

    def __unicode__(self):
        return unicode(self.name)

#def _get_default_country():
#    return Country.objects.get(iso2_code='IT')

###############################
# INDIRIZZO                   #
###############################
class Address (DateModel, UserModel, StatusModel, OrderedModel):
    ## ForeignKey
    address_scopes = models.ManyToManyField (
        AddressScope,
        db_index = True,
        verbose_name = _("address scopes"),
    )
    ## Campi
    address_type = models.IntegerField (
        default=7,
        choices = ADDRESS_TYPE_CHOICES,
        db_index = True,
        verbose_name = _("address type"),
        blank = True, null = True
    )
    name = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _("name"),
    )
    number = models.CharField (
        max_length = 20,
        blank = True, null = True,
        verbose_name = _("number"),
        db_column = "anumber" # number in alcuni db (come oracle) e' una parola
                              # riservata, quindi mettiamo come colonna del db
                              # anumber per avere la piena compatibilita
    )
    crossed = models.CharField (
        max_length = 5,
        blank = True, null = True,
        verbose_name = _("crossed"),
    )
    scale = models.CharField (
        max_length = 5,
        blank = True, null = True,
        verbose_name = _("scale"),
    )
    floor = models.CharField (
        max_length = 3,
        blank = True, null = True,
        verbose_name = _("floor"),
    )
    zip_code = models.CharField (
        max_length = 20,
        db_index = True,
        verbose_name = _("zip code"),
        blank = True, null = True,
    )
    locality = models.CharField (
        max_length = 100,
        db_index = True,
        verbose_name = _("locality"),
        blank = True, null = True,
    )
    ## FIXME da sistemare (rifNazione, rifProvincia)
    province = models.CharField (
        max_length = 2,
        db_index = True,
        verbose_name = _("province"),
        blank = True, null = True,
    )
    # FIXME
#    country = models.ForeignKey (
#        Country,
#        db_index = True,
#        default = 108, # id of Italy Country
#        verbose_name = _("country"),
#    )
    post_office = models.CharField (
        max_length = 10,
        blank = True, null = True,
        verbose_name = _("post office"),
    )

    def get_scopes(self):
        list_scopes = ""
        scopes = self.address_scopes.all()
        names = [ scope.name for  scope in scopes ]
        return ", ".join(names)
    get_scopes.short_description = _("scopes")

    def get_organizations(self):
        list_organizations = ""
        organizations = self.organization_set.all()
        names = [ organization.name for organization in organizations ]
        return ", ".join(names)
    get_organizations.short_description = _("organizations")

    def get_gmaps_address(self):
        return "%(address_type)s %(name)s, %(number)s, %(cap)s, %(locality)s" % {
                    'address_type': self.get_address_type_display() or '',
                    'name': self.name, 
                    'number': self.number, 
                    'locality': self.locality, 
                    'cap': self.zip_code or ''}
    gmaps_address = property(get_gmaps_address)

    class Meta:
        verbose_name = _("address")
        verbose_name_plural = _("addresses")
        abstract = True

    def __unicode__(self):
        return u"%(address_type)s %(name)s, %(number)s... - %(locality)s (%(province)s) - %(country)s" % {
            'address_type': self.get_address_type_display(),
            'name': self.name, 'number': self.number,
            'locality': self.locality, 'province': self.province,
            'country': self.country
        }

